Skip to main content Crate eip4844 Copy item path Source constants Context TrustedSetup Represents an Ethereum trusted setup used for KZG commitments on the BLS12-381 curve. Error Re-exported types
Top-level error type for EIP-4844 verification and serialization operations. SerializationError Re-exported types
Errors that can occur during deserialization of untrusted input from the public API
or the trusted setup. VerifierError Re-exported types
Errors that can occur when verifying a blob proof using the Verifier API. BlobRef BlobRef denotes a references to an opaque Blob.Bytes48Ref Bytes48Ref denotes a reference to an untrusted cryptographic type
that can be represented in 48 bytes. This will be either a
purported KZGProof or a purported KZGCommitment.Cell Cell contains a group of evaluations on a coset that one would like to
make and verify opening proofs about. CellRef CellRef contains a reference to a Cell.KZGCommitment KZGCommitment denotes a 48 byte commitment to a polynomial f(x)
that we would like to make and verify opening proofs about.KZGProof KZGProof denotes a 48 byte commitment to a polynomial that one can use to either:SerializedScalar SerializedScalar denotes a 32 byte field element.